@@ -26,12 +26,12 @@
 #include <QTimer>
 
 // KDE includes
-#include <kdebug.h>
 
 // local includes
 #include "abstractdisplay.h"
-#include "thememanager.h"
 #include "deck.h"
+#include "lskat_debug.h"
+#include "thememanager.h"
 
 // Forward declaration
 class Player;
@@ -61,12 +61,12 @@ public:
      * Main theme function. Called by the theme manager. Redraw and resize
      * display.
      */
-    virtual void changeTheme();
+    void changeTheme() override;
 
     /**
      * Start the intro.
      */
-    void start();
+    void start() override;
 
     /*
      * Deal cards - unused.
@@ -78,24 +78,24 @@ public:
     /**
      * Play a card on the display - unsused.
      */
-    void play(int /*cardNumber*/, int /*playerNumber*/, int /*phase*/) {}
+    void play(int /*cardNumber*/, int /*playerNumber*/, int /*phase*/) override {}
 
     /**
      * Turn a card on the display - unused.
      */
-    void turn(int /*cardNumber*/) {}
+    void turn(int /*cardNumber*/) override {}
 
     /**
      * Remove the given card from the display - unused.
      */
-    void remove(int /*winnerPosition*/, int /*cardNumber*/, int /*delta*/) {}
+    void remove(int /*winnerPosition*/, int /*cardNumber*/, int /*delta*/) override {}
 
 public slots:
     /**
      * Convert the position of a mouse click to a logical
      * game position - unused.
      */
-    void convertMousePress(const QPoint &/*mouse*/, int &/*playerNumber*/, int &/*cardNumber*/) {}
+    void convertMousePress(const QPoint &/*mouse*/, int &/*playerNumber*/, int &/*cardNumber*/) override {}
 
     /**
      * Animation loop. Called by timer.
